#pragma once
#include "pilot.h"

/**
 * @struct FleetPilot
 *
 * @brief Represents a pilot in a fleet.
 *
 * @sa Fleet
 * @sa Pilot
 */
typedef struct FleetPilot_ {
  Ship* ship; /**< Ship the pilot is flying. */
  char* name; /**< Used if they have a special name like uniques. */
  int chance; /**< Chance of this pilot appearing in the fleet. */
  char* ai;   /**< ai different of fleets global ai. */
} FleetPilot;

/**
 * @struct Fleet
 *
 * @brief Represenets a fleet.
 *
 * Fleets are used to create pilots, both from being in a system and from
 * mission triggers.
 *
 * @sa FleetPilot
 * @sa FleetGroup
 */
typedef struct Fleet_ {
  char* name;         /**< Fleet name, used as the identifier. */
  int faction;        /**< Faction of the fleet. */
  char* ai;           /**< faction of the fleet. */
  FleetPilot* pilots; /**< The pilots in the fleet. */
  int npilots;        /**< Total number of pilots. */
} Fleet;

/**
 * @brief Represents a group of fleets.
 *
 * Used to simplify creation of star systems and easily synchonize all systems.
 * with new ship additions.
 *
 * @sa Fleet
 */
typedef struct FleetGroup_ {
  char* name;     /** Name of the fleetgroup, used as the identifier. */
  Fleet** fleets; /**< List of fleets in the group. */
  int* chance;    /**< Chance of each fleet in the group. */
  int nfleets;    /**< Number of fleets in the group. */
} FleetGroup;

/*
 * Get fleet stuff.
 */
Fleet* fleet_get(const char* name);
FleetGroup* fleet_getGroup(const char* name);

/*
 * Load / cleanup.
 */
int fleet_load(void);
void fleet_free(void);

