#pragma once

#include "lua.h"
#include "lauxlib.h"
#include "lualib.h"

/* Debug stuff. */
#ifdef DEBUGGING
#ifdef DEBUG_PARANOID
#define LLUA_DEBUG(str, args...) \
  (fprintf(stdout, "Lua: "str"\n", ## args), abort())
#else
#define LLUA_DEBUG(str, args...) \
  (fprintf(stdout, "Lua: "str"\n", ## args))
#endif

#define LLUA_INVALID_PARAMETER() { \
  luaL_error(L, "Invalid parameter for %s.", __func__); \
  return 0; \
}

#define LLUA_MIN_ARGS(n) \
  if(lua_gettop(L) < n) { \
    luaL_error(L, "Too few arguments for %s.", __func__); \
    return 0; \
  }
#else /* DEBUGGING. */
#define LLUA_DEBUG(str, args...)  do {;} while(0)
#define LLUA_MIN_ARGS(n)          do {;} while(0)
#define LLUA_INVALID_PARAMETER()  do {;} while(0)
#endif /* DEBUGGING. */

/* Comfortability macros. */
#define luaL_dobuffer(L, b, n, s) \
  (luaL_loadbuffer(L, b, n, s) || lua_pcall(L, 0, LUA_MULTRET, 0))

