/**
 * @file pause.c
 *
 * @brief Handles pausing and resuming the game.
 *
 * Main trick to pausing/unpausing is to allow things based on time
 * to behave properly when the toolkit opens a window.
 */

#include "player.h"
#include "pause.h"

int paused    = 0;  /**< Are we paused. */
double dt_mod = 1.; /**< dt modifier. */

/* Pause the game. */
void pause_game(void) {
  if(paused) return; /* Well well.. We are paused already. */

  player_soundPause();

  paused = 1; /* We should unpause it. */
}

void unpause_game(void) {
  if(!paused) return; /* We are unpaused already. */

  player_soundResume();

  paused = 0;
}

/**
 * @brief Set the timers back.
 *    @param delay Delay to set timers back.
 */
void pause_delay(unsigned int delay) {
  (void)delay;
}

/**
 * @brief Adjust the game's dt modifier.
 */
void pause_setSpeed(double mod) {
  dt_mod = mod;
}

